@@ -49,6 +49,12 @@
 /* else it's in sys/types.h, included above */
 #endif
 
+/* We make several calls to asprintf, chdir, fgets and ignore the
+ * result.  Since this is a minimal init system there's nothing we can
+ * do if these calls fail.
+ */
+#pragma GCC diagnostic ignored "-Wunused-result"
+
 /* Maximum time to wait for the root device to appear (seconds).
  *
  * On slow machines with lots of disks (Koji running the 255 disk test
@@ -273,8 +279,8 @@ main ()
     fprintf (stderr, "supermin: deleting initramfs files\n");
   delete_initramfs_files ();
 
-  /* Note that pivot_root won't work.  See the note in
-   * Documentation/filesystems/ramfs-rootfs-initramfs.txt
+  /* Note that pivot_root won't work.  See the note in Linux
+   * Documentation/filesystems/ramfs-rootfs-initramfs.rst
    */
   if (!quiet)
     fprintf (stderr, "supermin: chroot\n");
